==> kirigami-addons-1.10.0-1.gpkg.tar: image/usr/lib64/cmake/KF6KirigamiAddons/KirigamiAddonsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KirigamiApp" for configuration "RelWithDebInfo"
set_property(TARGET KirigamiApp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KirigamiApp PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt6::QuickControls2;Qt6::Qml;KF6::CoreAddons;KF6::I18n;KF6::ColorScheme;KF6::Crash;KF6::IconThemes"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKirigamiApp.so.1.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libKirigamiApp.so.6"
  )

list(APPEND _cmake_import_check_targets KirigamiApp )
list(APPEND _cmake_import_check_files_for_KirigamiApp "${_IMPORT_PREFIX}/lib64/libKirigamiApp.so.1.10.0" )

# Import target "KirigamiAddonsStatefulApp" for configuration "RelWithDebInfo"
set_property(TARGET KirigamiAddonsStatefulApp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KirigamiAddonsStatefulApp PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::I18n;KF6::CoreAddons"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKirigamiAddonsStatefulApp.so.1.10.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libKirigamiAddonsStatefulApp.so.6"
  )

list(APPEND _cmake_import_check_targets KirigamiAddonsStatefulApp )
list(APPEND _cmake_import_check_files_for_KirigamiAddonsStatefulApp "${_IMPORT_PREFIX}/lib64/libKirigamiAddonsStatefulApp.so.1.10.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kirigami-addons-1.11.0-1.gpkg.tar: image/usr/lib64/cmake/KF6KirigamiAddons/KirigamiAddonsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KirigamiApp" for configuration "RelWithDebInfo"
set_property(TARGET KirigamiApp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KirigamiApp PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt6::QuickControls2;Qt6::Qml;KF6::CoreAddons;KF6::I18n;KF6::ColorScheme;Qt6::Widgets;KF6::Crash;KF6::IconThemes"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKirigamiApp.so.1.11.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libKirigamiApp.so.6"
  )

list(APPEND _cmake_import_check_targets KirigamiApp )
list(APPEND _cmake_import_check_files_for_KirigamiApp "${_IMPORT_PREFIX}/lib64/libKirigamiApp.so.1.11.0" )

# Import target "KirigamiAddonsStatefulApp" for configuration "RelWithDebInfo"
set_property(TARGET KirigamiAddonsStatefulApp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KirigamiAddonsStatefulApp PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF6::I18n;KF6::CoreAddons"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib64/libKirigamiAddonsStatefulApp.so.1.11.0"
  IMPORTED_SONAME_RELWITHDEBINFO "libKirigamiAddonsStatefulApp.so.6"
  )

list(APPEND _cmake_import_check_targets KirigamiAddonsStatefulApp )
list(APPEND _cmake_import_check_files_for_KirigamiAddonsStatefulApp "${_IMPORT_PREFIX}/lib64/libKirigamiAddonsStatefulApp.so.1.11.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
